@@ -4,7 +4,6 @@ import zipfile
 import glob
 import subprocess
 import tarfile
-import gzip
 import numpy as np
 import datetime as dt
 import pandas as pd
@@ -282,36 +281,7 @@ def Extract_Data(input_file, output_folder):
         z.extractall(output_folder)
         z.close()
 
-@staticmethod
-def ExtractFromGZ(InputFile, OutputFile, delete=False):
-    """
-    ExtractFromGZ method extract data from the zip/.gz files,
-    save the data
 
-    Parameters
-    ----------
-    zip_filename : [str]
-        zipped file name .
-    outfilename : [str]
-        directory where the unzipped data must be
-                            stored.
-    delete : [bool]
-        True if you want to delete the zipped file after the extracting the data
-    Returns
-    -------
-    None.
-
-    """
-    with gzip.GzipFile(InputFile, "rb") as zf:
-        content = zf.read()
-        save_file_content = open(OutputFile, "wb")
-        save_file_content.write(content)
-
-    save_file_content.close()
-    zf.close()
-
-    if delete:
-        os.remove(InputFile)
 
 
 def Extract_Data_tar_gz(zip_filename, output_folder):
